import * as React from 'react';
import React__default, { useState } from 'react';
import { Grid, GridItem, Bullseye, Avatar, Button, Spinner, Popover, PopoverPosition, ValidatedOptions } from '@patternfly/react-core';
import { FormGroupContainer } from '@rhc-shared-components/form-group-container';
import { useField, useFormikContext } from 'formik';

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var css_248z = ".file-upload-component .hidden-items {\n  display: none !important;\n}\n.file-upload-component .main-upload-div {\n  height: 100px;\n}\n.file-upload-component .logo-frame {\n  width: 90%;\n  height: 90%;\n  border: 1px solid black;\n  display: flex;\n  justify-content: space-around;\n  align-items: center;\n}\n.file-upload-component .logo-frame .upload-logo {\n  max-width: 100%;\n  max-height: 100%;\n  -o-object-fit: contain;\n     object-fit: contain;\n}\n.file-upload-component .upload-button {\n  margin: 10px;\n  outline: none;\n}\n.file-upload-component .supported-types {\n  margin-left: 10px;\n  color: #6a6e73;\n}\n.file-upload-component .file-upload-error {\n  margin-left: 10px;\n}\n\n.question-icon-file-upload {\n  cursor: pointer;\n}";

const _excluded$1 = ["fileuploadType", "uploadState", "avatarImg", "children", "buttonMessage", "fileTypesAllowed", "maxSize", "uniqueId", "removeMessage", "fileUrl", "readonly", "message", "replaced", "replacedMessage", "onChange"];
var UploadStates;

(function (UploadStates) {
  UploadStates["INITIAL"] = "INITIAL";
  UploadStates["UPLOADING"] = "UPLOADING";
  UploadStates["DONE"] = "DONE";
})(UploadStates || (UploadStates = {}));

var FileUploadTypes;

(function (FileUploadTypes) {
  FileUploadTypes["AVATAR"] = "AVATAR";
  FileUploadTypes["LOGOFRAME"] = "LOGOFRAME";
})(FileUploadTypes || (FileUploadTypes = {}));

const FileUploadComponent = _ref => {
  let {
    fileuploadType,
    uploadState,
    avatarImg,
    buttonMessage,
    fileTypesAllowed = [],
    uniqueId = 'picture',
    removeMessage,
    fileUrl,
    readonly,
    message,
    replaced,
    replacedMessage,
    onChange
  } = _ref,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$1);

  const idString = rest.name.replace('.', '-');
  const [removeUploadedFile, setRemoveUploadedFile] = useState(false);
  const extensions = fileTypesAllowed !== undefined ? fileTypesAllowed.map(function (item) {
    if (!item.includes('/')) {
      return '.' + item;
    } else {
      return item;
    }
  }) : ['svg', 'png'];
  InsertCss$1();

  const onChangeHandler = event => {
    const fileInput = event.target;
    const fileData = fileInput.files;
    setRemoveUploadedFile(false);
    onChange(fileData, event);
  };

  return React__default.createElement("div", {
    className: 'file-upload-component'
  }, React__default.createElement(Grid, {
    className: 'main-upload-div'
  }, React__default.createElement(GridItem, {
    span: 2,
    rowSpan: 3
  }, React__default.createElement(Bullseye, null, fileuploadType === FileUploadTypes.AVATAR ? React__default.createElement(Avatar, {
    src: fileUrl && !removeUploadedFile ? fileUrl : avatarImg,
    alt: 'avatar',
    className: 'upload-avatar'
  }) : React__default.createElement("div", {
    className: 'logo-frame'
  }, (fileUrl || avatarImg) && React__default.createElement("img", {
    className: 'upload-logo',
    "data-testid": uniqueId,
    alt: uniqueId,
    src: fileUrl && !removeUploadedFile ? fileUrl : avatarImg
  })))), React__default.createElement(GridItem, {
    span: 10,
    rowSpan: 3
  }, fileUrl && !removeUploadedFile ? React__default.createElement(Button, {
    className: 'upload-button',
    id: 'upload-button-' + idString,
    variant: 'link',
    onClick: e => {
      if (replaced) {
        var _document$getElementB;

        (_document$getElementB = document.getElementById('filefield' + idString)) == null ? void 0 : _document$getElementB.click();
      } else {
        setRemoveUploadedFile(true); // Resetting file input

        const fileInput = document.getElementById('filefield' + idString);
        fileInput.value = '';
        onChangeHandler(e);
      }
    },
    isDisabled: readonly || uploadState === UploadStates.UPLOADING,
    isInline: true
  }, uploadState === UploadStates.UPLOADING && replaced ? React__default.createElement(Spinner, {
    size: 'md'
  }) : replaced ? replacedMessage : removeMessage) : React__default.createElement(Button, {
    className: 'upload-button',
    id: 'upload-button-' + idString,
    variant: 'link',
    onClick: () => {
      var _document$getElementB2;

      (_document$getElementB2 = document.getElementById('filefield' + idString)) == null ? void 0 : _document$getElementB2.click();
    },
    isDisabled: readonly || uploadState === UploadStates.UPLOADING,
    isInline: true
  }, uploadState === UploadStates.UPLOADING ? React__default.createElement(Spinner, {
    size: 'md'
  }) : buttonMessage), React__default.createElement("div", {
    className: 'supported-types'
  }, message))), React__default.createElement("input", {
    "data-testid": 'fileInput',
    id: 'filefield' + idString,
    onChange: e => onChangeHandler(e),
    type: 'file',
    className: 'hidden-items',
    accept: extensions.join(','),
    disabled: readonly
  }));
};

const InsertCss$1 = () => {
  const styleId = 'file-upload-component-styles';

  if (!document.getElementById(styleId)) {
    const styleTag = document.createElement('style');
    styleTag.id = styleId;
    styleTag.type = 'text/css';
    styleTag.innerHTML = css_248z;
    document.body.appendChild(styleTag);
  }
};

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
function __rest(s, e) {
  var t = {};

  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];

  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
}

var IconSize;
(function (IconSize) {
    IconSize["sm"] = "sm";
    IconSize["md"] = "md";
    IconSize["lg"] = "lg";
    IconSize["xl"] = "xl";
})(IconSize || (IconSize = {}));
const getSize = (size) => {
    switch (size) {
        case IconSize.sm:
            return '1em';
        case IconSize.md:
            return '1.5em';
        case IconSize.lg:
            return '2em';
        case IconSize.xl:
            return '3em';
        default:
            return '1em';
    }
};
let currentId = 0;
/**
 * Factory to create Icon class components for consumers
 */
function createIcon({ name, xOffset = 0, yOffset = 0, width, height, svgPath }) {
    var _a;
    return _a = class SVGIcon extends React.Component {
            constructor() {
                super(...arguments);
                this.id = `icon-title-${currentId++}`;
            }
            render() {
                const _a = this.props, { size, color, title, noVerticalAlign } = _a, props = __rest(_a, ["size", "color", "title", "noVerticalAlign"]);
                const hasTitle = Boolean(title);
                const heightWidth = getSize(size);
                const baseAlign = -0.125 * Number.parseFloat(heightWidth);
                const style = noVerticalAlign ? null : { verticalAlign: `${baseAlign}em` };
                const viewBox = [xOffset, yOffset, width, height].join(' ');
                return (React.createElement("svg", Object.assign({ style: style, fill: color, height: heightWidth, width: heightWidth, viewBox: viewBox, "aria-labelledby": hasTitle ? this.id : null, "aria-hidden": hasTitle ? null : true, role: "img" }, props),
                    hasTitle && React.createElement("title", { id: this.id }, title),
                    React.createElement("path", { d: svgPath })));
            }
        },
        _a.displayName = name,
        _a.defaultProps = {
            color: 'currentColor',
            size: IconSize.sm,
            noVerticalAlign: false
        },
        _a;
}

const OutlinedQuestionCircleIconConfig = {
  name: 'OutlinedQuestionCircleIcon',
  height: 512,
  width: 512,
  svgPath: 'M256 8C119.043 8 8 119.083 8 256c0 136.997 111.043 248 248 248s248-111.003 248-248C504 119.083 392.957 8 256 8zm0 448c-110.532 0-200-89.431-200-200 0-110.495 89.472-200 200-200 110.491 0 200 89.471 200 200 0 110.53-89.431 200-200 200zm107.244-255.2c0 67.052-72.421 68.084-72.421 92.863V300c0 6.627-5.373 12-12 12h-45.647c-6.627 0-12-5.373-12-12v-8.659c0-35.745 27.1-50.034 47.579-61.516 17.561-9.845 28.324-16.541 28.324-29.579 0-17.246-21.999-28.693-39.784-28.693-23.189 0-33.894 10.977-48.942 29.969-4.057 5.12-11.46 6.071-16.666 2.124l-27.824-21.098c-5.107-3.872-6.251-11.066-2.644-16.363C184.846 131.491 214.94 112 261.794 112c49.071 0 101.45 38.304 101.45 88.8zM298 368c0 23.159-18.841 42-42 42s-42-18.841-42-42 18.841-42 42-42 42 18.841 42 42z',
  yOffset: 0,
  xOffset: 0,
};

const OutlinedQuestionCircleIcon = createIcon(OutlinedQuestionCircleIconConfig);

const _excluded = ["label", "isRequired", "ariaLabel", "placeholder", "helperText", "buttonMessage", "maxItems", "maxHeight", "disabled", "uploadState", "fileuploadType", "avatarImg", "fileUrl", "fileTypesAllowed", "maxSize", "removeMessage", "uniqueId", "readonly", "message", "replaced", "replacedMessage", "onChange", "value", "labelIcon", "formGroupProps"];
const FileUploadFormComponent = _ref => {
  let {
    label,
    isRequired,
    ariaLabel = 'Enter text',
    helperText,
    buttonMessage,
    uploadState,
    fileuploadType,
    avatarImg,
    fileUrl,
    fileTypesAllowed,
    maxSize,
    removeMessage,
    uniqueId,
    readonly,
    message,
    replaced,
    replacedMessage,
    onChange,
    value,
    labelIcon,
    formGroupProps
  } = _ref,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded);

  if (!labelIcon) {
    labelIcon = React.createElement(Popover, {
      position: PopoverPosition.top,
      zIndex: 3,
      headerContent: React.createElement("div", null, "Logo best practices"),
      bodyContent: React.createElement("div", null, "If you have multiple logo format, we recommend use a logo with transparent background, no border, and square versus rectangular shape.")
    }, React.createElement("span", {
      className: 'question-icon-file-upload'
    }, React.createElement(OutlinedQuestionCircleIcon, null)));
  }

  const [, meta] = useField(rest);
  const {
    setFieldValue,
    validateField
  } = useFormikContext();
  InsertCss();
  React.useEffect(() => {
    setFieldValue(rest.name, value);
    validateField(rest.name);
  }, [value]);

  const handleChange = (data, event) => {
    setFieldValue(rest.name, value);
    onChange(data, event);
  };

  return React.createElement(FormGroupContainer, Object.assign({
    fieldId: rest.name,
    label: label,
    isRequired: isRequired,
    validated: meta.touched && meta.error ? ValidatedOptions.error : ValidatedOptions.default,
    helperTextInvalid: meta.error,
    helperText: helperText
  }, labelIcon && {
    labelIcon: labelIcon
  }, formGroupProps), React.createElement(FileUploadComponent, {
    name: rest.name,
    buttonMessage: buttonMessage,
    replaced: replaced,
    fileTypesAllowed: fileTypesAllowed,
    removeMessage: removeMessage,
    maxSize: maxSize,
    readonly: readonly,
    uniqueId: uniqueId,
    uploadState: uploadState,
    fileuploadType: fileuploadType,
    avatarImg: avatarImg,
    fileUrl: fileUrl,
    message: message,
    replacedMessage: replacedMessage,
    onChange: (data, event) => handleChange(data, event)
  }));
};

const InsertCss = () => {
  const styleId = 'file-upload-component-styles';

  if (!document.getElementById(styleId)) {
    const styleTag = document.createElement('style');
    styleTag.id = styleId;
    styleTag.type = 'text/css';
    styleTag.innerHTML = css_248z;
    document.body.appendChild(styleTag);
  }
};

export { FileUploadComponent, FileUploadFormComponent, FileUploadTypes, UploadStates };
